package com.yuda.hainafacetofaceai.service.impl;

import com.yuda.hainafacetofaceai.entity.CandidateExam;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.logging.Logger;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.json.JSONObject;

@Service
public class SeleniumService {

    private static final Logger logger = Logger.getLogger(SeleniumService.class.getName());
    private static final String driverPath = "D:/Game/chromedriver-win64/chromedriver-win64/chromedriver.exe";
    public void extractDataAndSaveToJson(List<CandidateExam> list) throws UnsupportedEncodingException {
        System.setProperty("webdriver.chrome.driver", driverPath);
        // 设置ChromeDriver路径
        for (CandidateExam candidateExam : list) {
            WebDriver driver = new ChromeDriver();
            String json = candidateExam.getInterviewResults();
            JSONObject object  = new JSONObject(json);
            String url = object.get("reportUrl").toString();
            Integer i = 0;
            Integer j = 0;
            // 创建WebDriver实例
            try {
                // 打开目标网页
                driver.get(url);
                // 等待元素可见
                WebDriverWait wait = new WebDriverWait(driver, 20);
                WebElement element = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector("#full > div.mainBox > div.big-card-con")));
                // 提取元素的HTML内容
                String elementHtml = element.getAttribute("outerHTML");
                // 使用Jsoup解析HTML
                Document doc = Jsoup.parse(elementHtml);
                List<Element> newQBlocks = doc.select(".new-q-block");
                Map<String, String> resultMap = new HashMap<>();
                // 遍历每个new-q-block元素
                for (Element block : newQBlocks) {
                    // 查找第一个class="P-inline"的元素并获取其文本内容作为键
                    Element keyElement = block.selectFirst(".P-inline");
                    String key = keyElement != null ? keyElement.text().trim() : null;
                    // 查找第二个class="content"的元素并获取其文本内容作为值
                    List<Element> valueElements = block.select(".content");
                    String value = valueElements.size() > 1 ? valueElements.get(1).text().trim() : null;
                    // 如果键和值都存在，则将其添加到字典中
                    if (key != null && value != null) {
                        resultMap.put(key, value);
                    }
                }
                // 打印提取的内容
                // 将结果保存为JSON文件
                String outputFile = "D:/jsonResults/"+candidateExam.getExamConnectCode()+"/"+candidateExam.getCandidateConnectCode()+"_ai.json";
                saveToJson(resultMap, outputFile);
                logger.info("结果已保存到: " + outputFile);
                logger.info("处理成功进度—ai_json:(面试编号)"+candidateExam.getExamConnectCode()+"_(候选人链接编号)"+candidateExam.getCandidateConnectCode()+"=成功"+(++i)+"/"+list.size());
            } catch (Exception e) {
                logger.info("处理成功进度—ai_json:(面试编号)"+candidateExam.getExamConnectCode()+"_(候选人链接编号)"+candidateExam.getCandidateConnectCode()+"=失败"+(++j)+"/"+list.size());
            } finally {
                driver.quit();
            }
        }
    }

    private void saveToJson(Map<String, String> data, String filePath) throws IOException {
        String json = new JSONObject(data).toString(4);
        Files.write(Paths.get(filePath), json.getBytes());
    }
}
